"""
This file defines colores as a module.
"""

from .core import *

# Package Meta Data
__version__ = "0.1.0"
__authors__ = ["Eliaz Bobadilla <eliaz.bobadilladev@gmail.com>"]
__author_email__ = "eliaz.bobadilladev@gmail.com"
__url__ = "https://github.com/UltiRequiem/colores"
__package_name__ = "colores"
